@@ -7,8 +7,9 @@ this file contains standard routines
 import numpy as np
 import mpmath
 import itertools
-
+from lenstronomy.Util.numba_util import jit
 from lenstronomy.Util.package_util import exporter
+
 export, __all__ = exporter()
 
 
@@ -25,15 +26,13 @@ def merge_dicts(*dict_args):
 
 
 @export
-def approx_theta_E(ximg,yimg):
-
+def approx_theta_E(ximg, yimg):
     dis = []
-    xinds,yinds = [0,0,0,1,1,2],[1,2,3,2,3,3]
+    xinds, yinds = [0, 0, 0, 1, 1, 2], [1, 2, 3, 2, 3, 3]
 
-    for (i,j) in zip(xinds,yinds):
-
-        dx,dy = ximg[i] - ximg[j], yimg[i] - yimg[j]
-        dr = (dx**2+dy**2)**0.5
+    for (i, j) in zip(xinds, yinds):
+        dx, dy = ximg[i] - ximg[j], yimg[i] - yimg[j]
+        dr = (dx ** 2 + dy ** 2) ** 0.5
         dis.append(dr)
     dis = np.array(dis)
 
@@ -44,12 +43,11 @@ def approx_theta_E(ximg,yimg):
     second_greatest = np.argmax(dis)
     dr_second = dis[second_greatest]
 
-    return 0.5*(dr_greatest*dr_second)**0.5
+    return 0.5 * (dr_greatest * dr_second) ** 0.5
 
 
 @export
-def sort_image_index(ximg,yimg,xref,yref):
-
+def sort_image_index(ximg, yimg, xref, yref):
     """
 
     :param ximg: x coordinates to sort
@@ -60,7 +58,7 @@ def sort_image_index(ximg,yimg,xref,yref):
     """
 
     assert len(xref) == len(ximg)
-    ximg,yimg = np.array(ximg),np.array(yimg)
+    ximg, yimg = np.array(ximg), np.array(yimg)
     x_self = np.array(list(itertools.permutations(ximg)))
     y_self = np.array(list(itertools.permutations(yimg)))
 
@@ -81,6 +79,7 @@ def sort_image_index(ximg,yimg,xref,yref):
 
 
 @export
+@jit()
 def rotate(xcoords, ycoords, angle):
     """
 
@@ -89,7 +88,7 @@ def rotate(xcoords, ycoords, angle):
     :param angle: angle in radians
     :return: x points and y points rotated ccw by angle theta
     """
-    return xcoords*np.cos(angle)+ycoords*np.sin(angle), -xcoords*np.sin(angle)+ycoords*np.cos(angle)
+    return xcoords * np.cos(angle) + ycoords * np.sin(angle), -xcoords * np.sin(angle) + ycoords * np.cos(angle)
 
 
 @export
@@ -121,8 +120,8 @@ def array2image(array, nx=0, ny=0):
     """
     if nx == 0 or ny == 0:
         n = int(np.sqrt(len(array)))
-        if n**2 != len(array):
-            raise ValueError("lenght of input array given as %s is not square of integer number!" %(len(array)))
+        if n ** 2 != len(array):
+            raise ValueError("lenght of input array given as %s is not square of integer number!" % (len(array)))
         nx, ny = n, n
     image = array.reshape(int(nx), int(ny))
     return image
@@ -139,7 +138,7 @@ def image2array(image):
     :raises: AttributeError, KeyError
     """
     nx, ny = image.shape  # find the size of the array
-    imgh = np.reshape(image, nx*ny)  # change the shape to be 1d
+    imgh = np.reshape(image, nx * ny)  # change the shape to be 1d
     return imgh
 
 
@@ -147,7 +146,7 @@ def image2array(image):
 def array2cube(array, n_1, n_23):
     """
     returns the information contained in a 1d array of shape (n_1*n_23*n_23) into 3d array with shape (n_1, sqrt(n_23), sqrt(n_23))
-    
+
     :param array: image values
     :type array: 1d array
     :param n_1: first dimension of returned array
@@ -158,7 +157,7 @@ def array2cube(array, n_1, n_23):
     :raises ValueError: when n_23 is not a perfect square
     """
     n = int(np.sqrt(n_23))
-    if n**2 != n_23:
+    if n ** 2 != n_23:
         raise ValueError("2nd and 3rd dims (%s) are not square of integer number!" % n_23)
     n_2, n_3 = n, n
     cube = array.reshape(n_1, n_2, n_3)
@@ -169,7 +168,7 @@ def array2cube(array, n_1, n_23):
 def cube2array(cube):
     """
     returns the information contained in a 3d array of shape (n_1, n_2, n_3) into 1d array with shape (n_1*n_2*n_3)
-    
+
     :param array: image values
     :type array: 3d array
     :returns: 1d array
@@ -177,7 +176,7 @@ def cube2array(cube):
     n_1, n_2, n_3 = cube.shape
     array = cube.reshape(n_1 * n_2 * n_3)
     return array
-    
+
 
 @export
 def make_grid(numPix, deltapix, subgrid_res=1, left_lower=False):
@@ -205,8 +204,8 @@ def make_grid(numPix, deltapix, subgrid_res=1, left_lower=False):
         numPix = np.array([numPix, numPix], dtype=np.int)
 
     # Super-resolution sampling
-    numPix_eff = (numPix*subgrid_res).astype(np.int)
-    deltapix_eff = deltapix/float(subgrid_res)
+    numPix_eff = (numPix * subgrid_res).astype(np.int)
+    deltapix_eff = deltapix / float(subgrid_res)
 
     # Compute unshifted grids.
     # X values change quickly, Y values are repeated many times
@@ -238,7 +237,8 @@ def make_grid_transformed(numPix, Mpix2Angle):
 
 
 @export
-def make_grid_with_coordtransform(numPix, deltapix, subgrid_res=1, center_ra=0, center_dec=0, left_lower=False, inverse=True):
+def make_grid_with_coordtransform(numPix, deltapix, subgrid_res=1, center_ra=0, center_dec=0, left_lower=False,
+                                  inverse=True):
     """
     same as make_grid routine, but returns the transformation matrix and shift between coordinates and pixel
 
@@ -251,8 +251,8 @@ def make_grid_with_coordtransform(numPix, deltapix, subgrid_res=1, center_ra=0,
     :param inverse: bool, if true sets East as left, otherwise East is righrt
     :return:
     """
-    numPix_eff = numPix*subgrid_res
-    deltapix_eff = deltapix/float(subgrid_res)
+    numPix_eff = numPix * subgrid_res
+    deltapix_eff = deltapix / float(subgrid_res)
     a = np.arange(numPix_eff)
     matrix = np.dstack(np.meshgrid(a, a)).reshape(-1, 2)
     if inverse is True:
@@ -263,9 +263,9 @@ def make_grid_with_coordtransform(numPix, deltapix, subgrid_res=1, center_ra=0,
         ra_grid = matrix[:, 0] * delta_x
         dec_grid = matrix[:, 1] * deltapix_eff
     else:
-        ra_grid = (matrix[:, 0] - (numPix_eff-1)/2.) * delta_x
-        dec_grid = (matrix[:, 1] - (numPix_eff-1)/2.) * deltapix_eff
-    shift = (subgrid_res-1)/(2.*subgrid_res)*deltapix
+        ra_grid = (matrix[:, 0] - (numPix_eff - 1) / 2.) * delta_x
+        dec_grid = (matrix[:, 1] - (numPix_eff - 1) / 2.) * deltapix_eff
+    shift = (subgrid_res - 1) / (2. * subgrid_res) * deltapix
     ra_grid -= shift + center_ra
     dec_grid -= shift + center_dec
     ra_at_xy_0 = ra_grid[0]
@@ -308,13 +308,13 @@ def get_axes(x, y):
     :param y:
     :return:
     """
-    n=int(np.sqrt(len(x)))
-    if n**2 != len(x):
+    n = int(np.sqrt(len(x)))
+    if n ** 2 != len(x):
         raise ValueError("lenght of input array given as %s is not square of integer number!" % (len(x)))
-    x_image = x.reshape(n,n)
-    y_image = y.reshape(n,n)
-    x_axes = x_image[0,:]
-    y_axes = y_image[:,0]
+    x_image = x.reshape(n, n)
+    y_image = y.reshape(n, n)
+    x_axes = x_image[0, :]
+    y_axes = y_image[:, 0]
     return x_axes, y_axes
 
 
@@ -330,7 +330,7 @@ def averaging(grid, numGrid, numPix):
 
     Nbig = numGrid
     Nsmall = numPix
-    small = grid.reshape([int(Nsmall), int(Nbig/Nsmall), int(Nsmall), int(Nbig/Nsmall)]).mean(3).mean(1)
+    small = grid.reshape([int(Nsmall), int(Nbig / Nsmall), int(Nsmall), int(Nbig / Nsmall)]).mean(3).mean(1)
     return small
 
 
@@ -348,7 +348,7 @@ def displaceAbs(x, y, sourcePos_x, sourcePos_y):
     """
     x_mapped = x - sourcePos_x
     y_mapped = y - sourcePos_y
-    absmapped = np.sqrt(x_mapped**2+y_mapped**2)
+    absmapped = np.sqrt(x_mapped ** 2 + y_mapped ** 2)
     return absmapped
 
 
@@ -363,13 +363,13 @@ def get_distance(x_mins, y_mins, x_true, y_true):
     :return:
     """
     if len(x_mins) != len(x_true):
-        return 10**10
+        return 10 ** 10
     dist = 0
     x_true_list = np.array(x_true)
     y_true_list = np.array(y_true)
 
-    for i in range(0,len(x_mins)):
-        dist_list = (x_mins[i] - x_true_list)**2 + (y_mins[i] - y_true_list)**2
+    for i in range(0, len(x_mins)):
+        dist_list = (x_mins[i] - x_true_list) ** 2 + (y_mins[i] - y_true_list) ** 2
         dist += min(dist_list)
         k = np.where(dist_list == min(dist_list))
         if type(k) != int:
@@ -388,11 +388,11 @@ def compare_distance(x_mapped, y_mapped):
     :return: sum of distance square of positions
     """
     X2 = 0
-    for i in range(0, len(x_mapped)-1):
-        for j in range(i+1, len(x_mapped)):
-            dx = x_mapped[i]-x_mapped[j]
-            dy = y_mapped[i]-y_mapped[j]
-            X2 += dx**2+dy**2
+    for i in range(0, len(x_mapped) - 1):
+        for j in range(i + 1, len(x_mapped)):
+            dx = x_mapped[i] - x_mapped[j]
+            dy = y_mapped[i] - y_mapped[j]
+            X2 += dx ** 2 + dy ** 2
     return X2
 
 
@@ -408,7 +408,7 @@ def min_square_dist(x_1, y_1, x_2, y_2):
     """
     dist = np.zeros_like(x_1)
     for i in range(len(x_1)):
-        dist[i] = np.min((x_1[i] - x_2)**2 + (y_1[i] - y_2)**2)
+        dist[i] = np.min((x_1[i] - x_2) ** 2 + (y_1[i] - y_2) ** 2)
     return dist
 
 
@@ -430,7 +430,7 @@ def selectBest(array, criteria, numSelect, highest=True):
         return array
     array_sorted = array[criteria.argsort()]
     if highest:
-        result = array_sorted[n-numSelect:]
+        result = array_sorted[n - numSelect:]
     else:
         result = array_sorted[0:numSelect]
     return result[::-1]
@@ -456,25 +456,30 @@ def select_best(array, criteria, num_select, highest=True):
     if highest is True:
         indexes = criteria.argsort()[::-1][:num_select]
     else:
-        indexes = criteria.argsort()[::-1][n-num_select:]
+        indexes = criteria.argsort()[::-1][n - num_select:]
     return array[indexes]
 
 
 @export
-def points_on_circle(radius, num_points):
+def points_on_circle(radius, num_points, connect_ends=True):
     """
     returns a set of uniform points around a circle
     :param radius: radius of the circle
     :param num_points: number of points on the circle
-    :return:
+    :param connect_ends: boolean, if True, start and end point are the same
+    :return: x-coords, y-coords of points on the circle
     """
-    angle = np.linspace(0, 2 * np.pi, num_points)
-    x_coord = np.cos(angle)*radius
-    y_coord = np.sin(angle)*radius
+    if connect_ends:
+        angle = np.linspace(0, 2 * np.pi, num_points)
+    else:
+        angle = np.linspace(0, 2 * np.pi * (1 - 1./num_points), num_points)
+    x_coord = np.cos(angle) * radius
+    y_coord = np.sin(angle) * radius
     return x_coord, y_coord
 
 
 @export
+@jit()
 def neighborSelect(a, x, y):
     """
     #TODO replace by from scipy.signal import argrelextrema for speed up
@@ -501,34 +506,30 @@ def neighborSelect(a, x, y):
     values = []
     x_mins = []
     y_mins = []
-    for i in range(dim+1,len(a)-dim-1):
-        if (a[i] < a[i-1]
-            and a[i] < a[i+1]
-            and a[i] < a[i-dim]
-            and a[i] < a[i+dim]
-            and a[i] < a[i-(dim-1)]
-            and a[i] < a[i-(dim+1)]
-            and a[i] < a[i+(dim-1)]
-            and a[i] < a[i+(dim+1)]):
-                if(a[i] < a[(i-2*dim-1)%dim**2]
-                    and a[i] < a[(i-2*dim+1)%dim**2]
-                    and a[i] < a[(i-dim-2)%dim**2]
-                    and a[i] < a[(i-dim+2)%dim**2]
-                    and a[i] < a[(i+dim-2)%dim**2]
-                    and a[i] < a[(i+dim+2)%dim**2]
-                    and a[i] < a[(i+2*dim-1)%dim**2]
-                    and a[i] < a[(i+2*dim+1)%dim**2]):
-                    if(a[i] < a[(i-3*dim-1)%dim**2]
-                        and a[i] < a[(i-3*dim+1)%dim**2]
-                        and a[i] < a[(i-dim-3)%dim**2]
-                        and a[i] < a[(i-dim+3)%dim**2]
-                        and a[i] < a[(i+dim-3)%dim**2]
-                        and a[i] < a[(i+dim+3)%dim**2]
-                        and a[i] < a[(i+3*dim-1)%dim**2]
-                        and a[i] < a[(i+3*dim+1)%dim**2]):
-                        x_mins.append(x[i])
-                        y_mins.append(y[i])
-                        values.append(a[i])
+    for i in range(dim + 1, len(a) - dim - 1):
+        if (a[i] < a[i - 1]
+                and a[i] < a[i + 1]
+                and a[i] < a[i - dim]
+                and a[i] < a[i + dim]
+                and a[i] < a[i - (dim - 1)]
+                and a[i] < a[i - (dim + 1)]
+                and a[i] < a[i + (dim - 1)]
+                and a[i] < a[i + (dim + 1)]):
+            if (a[i] < a[(i - 2 * dim - 1) % dim ** 2]
+                    and a[i] < a[(i - 2 * dim + 1) % dim ** 2]
+                    and a[i] < a[(i - dim - 2) % dim ** 2]
+                    and a[i] < a[(i - dim + 2) % dim ** 2]
+                    and a[i] < a[(i + dim - 2) % dim ** 2]
+                    and a[i] < a[(i + dim + 2) % dim ** 2]
+                    and a[i] < a[(i + 2 * dim - 1) % dim ** 2]
+                    and a[i] < a[(i + 2 * dim + 1) % dim ** 2]
+                    and a[i] < a[(i + 2 * dim) % dim ** 2]
+                    and a[i] < a[(i - 2 * dim) % dim ** 2]
+                    and a[i] < a[(i - 2) % dim ** 2]
+                    and a[i] < a[(i + 2) % dim ** 2]):
+                x_mins.append(x[i])
+                y_mins.append(y[i])
+                values.append(a[i])
     return np.array(x_mins), np.array(y_mins), np.array(values)
 
 
@@ -592,12 +593,18 @@ def make_subgrid(ra_coord, dec_coord, subgrid_res=2):
     d_dec_x = dec_array[0][1] - dec_array[0][0]
     d_dec_y = dec_array[1][0] - dec_array[0][0]
 
-    ra_array_new = np.zeros((n*subgrid_res, n*subgrid_res))
-    dec_array_new = np.zeros((n*subgrid_res, n*subgrid_res))
+    ra_array_new = np.zeros((n * subgrid_res, n * subgrid_res))
+    dec_array_new = np.zeros((n * subgrid_res, n * subgrid_res))
     for i in range(0, subgrid_res):
         for j in range(0, subgrid_res):
-            ra_array_new[i::subgrid_res, j::subgrid_res] = ra_array + d_ra_x * (-1/2. + 1/(2.*subgrid_res) + j/float(subgrid_res)) + d_ra_y * (-1/2. + 1/(2.*subgrid_res) + i/float(subgrid_res))
-            dec_array_new[i::subgrid_res, j::subgrid_res] = dec_array + d_dec_x * (-1/2. + 1/(2.*subgrid_res) + j/float(subgrid_res)) + d_dec_y * (-1/2. + 1/(2.*subgrid_res) + i/float(subgrid_res))
+            ra_array_new[i::subgrid_res, j::subgrid_res] = ra_array + d_ra_x * (
+                        -1 / 2. + 1 / (2. * subgrid_res) + j / float(subgrid_res)) + d_ra_y * (
+                                                                       -1 / 2. + 1 / (2. * subgrid_res) + i / float(
+                                                                   subgrid_res))
+            dec_array_new[i::subgrid_res, j::subgrid_res] = dec_array + d_dec_x * (
+                        -1 / 2. + 1 / (2. * subgrid_res) + j / float(subgrid_res)) + d_dec_y * (
+                                                                        -1 / 2. + 1 / (2. * subgrid_res) + i / float(
+                                                                    subgrid_res))
 
     ra_coords_sub = image2array(ra_array_new)
     dec_coords_sub = image2array(dec_array_new)
@@ -633,7 +640,7 @@ def convert_bool_list(n, k=None):
         bool_list = [False] * n
         for i, k_i in enumerate(k):
             if k_i is not False:
-                #if k_i is True:
+                # if k_i is True:
                 #    bool_list[i] = True
                 if k_i < n:
                     bool_list[k_i] = True
@@ -641,4 +648,4 @@ def convert_bool_list(n, k=None):
                     raise ValueError("k as set by %s is not convertable in a bool string!" % k)
     else:
         raise ValueError('input list k as %s not compatible' % k)
-    return bool_list
+    return bool_list
\ No newline at end of file
