@@ -17,8 +17,8 @@ class TestSersicEllipseGaussDec(object):
     """
     def setup(self):
         self.sersic_gauss = SersicEllipseGaussDec()
-        self.sersic_light = SersicElliptic()
-        self.sersic_sphere = Sersic()
+        self.sersic_light = SersicElliptic(sersic_major_axis=False)
+        self.sersic_sphere = Sersic(sersic_major_axis=False)
 
     def test_function(self):
         """
@@ -200,9 +200,9 @@ class TestSersicEllipseGaussDec(object):
                                                     R_sersic=R_sersic,
                                                     k_eff=k_eff)
 
-        assert np.all(
-            np.abs(sersic_analytic - sersic_gauss) / np.sqrt(sersic_analytic)
-            * 100. < 1.)
+        print(np.abs(sersic_analytic - sersic_gauss) / np.sqrt(sersic_analytic))
+
+        assert np.all(np.abs(sersic_analytic - sersic_gauss) / np.sqrt(sersic_analytic) * 100. < 1.)
 
     def test_gauss_decompose_sersic(self):
         """
